==> tagmemo_0_1.zip: tagmemo/language/english/main.php <==
<?php
/**
* @package languege
* @ignore
*/

define('_MD_TAGMEMO_CREATE', "TagMemo");
define('_MD_TAGMEMO_TITLE', "Title");
define('_MD_TAGMEMO_TAGS', "Tag");
define('_MD_TAGMEMO_DESC', "Description");
define('_MD_TAGMEMO_CANCELL', "Cancel");
define('_MD_TAGMEMO_DELETE', "Delete");
define('_MD_TAGMEMO_SAVE', "Autosave");
define('_MD_TAGMEMO_DONE', "Save/Close");
define('_MD_TAGMEMO_PUBLIC', "Set to the public");
define('_MD_TAGMEMO_ON', "Public");
//define('_MD_TAGMEMO_OFF', "Private");
define('_MD_TAGMEMO_DATETIME', "Datetime"); // check
define('_MD_TAGMEMO_EDIT', "Edit");
define('_MD_TAGMEMO_MESSAGE_SAVE', "Saved"); // check
define('_MD_TAGMEMO_MESSAGE_DELETE', "Deleted"); // check
define('_MD_TAGMEMO_LIST_E', "List");
define('_MD_TAGMEMO_EDIT_E', "Edit");
define('_MD_TAGMEMO_EDIT_W', "Write");
define('_MD_TAGMEMO_TAGS_E', "Tags");
define('_MD_TAGMEMO_TAGS_N', "New");
define('_MD_TAGMEMO_TAGS_P', "Populer");
define('_MD_TAGMEMO_MESSAGE_DELETE_CONFIRM', "You are going to delete this memo\nAre you sure?"); // check
define('_MD_TAGMEMO_IMG_LIST', "Go to Memolist");
define('_MD_TAGMEMO_IMG_EDIT', "Write new memo ");
define('_MD_TAGMEMO_IMG_CLOUD', "Go to Tag Cloud");
define('_MD_TAGMEMO_TAGCLICK_DELETE', "Click to delete");
define('_MD_TAGMEMO_PLUGIN_FFSEARCH', "Add Search plug-in of Firefox");
define('_MD_TAGMEMO_BOOKMARKLET', "Bookmarklet");
//define('_MD_TAGMEMO_SEARCH', "Search");
//define('_MD_TAGMEMO_SEARCH_ALL', "All");
//define('_MD_TAGMEMO_SEARCH_SUB', "In this list");
?>

==> tagmemo_0.2.zip: tagmemo/language/english/main.php <==
<?php
/**
* @package languege
* @ignore
*/

define('_MD_TAGMEMO_CREATE', "TagMemo");
define('_MD_TAGMEMO_TITLE', "Title");
define('_MD_TAGMEMO_TAGS', "Tag");
define('_MD_TAGMEMO_DESC', "Description");
define('_MD_TAGMEMO_CANCELL', "Cancel");
define('_MD_TAGMEMO_DELETE', "Delete");
define('_MD_TAGMEMO_SAVE', "Autosave");
define('_MD_TAGMEMO_DONE', "Save/Close");
define('_MD_TAGMEMO_PUBLIC', "Set to the public");
define('_MD_TAGMEMO_ON', "Public");
//define('_MD_TAGMEMO_OFF', "Private");
define('_MD_TAGMEMO_DATETIME', "Datetime"); // check
define('_MD_TAGMEMO_EDIT', "Edit");
define('_MD_TAGMEMO_MESSAGE_SAVE', "Saved"); // check
define('_MD_TAGMEMO_MESSAGE_DELETE', "Deleted"); // check
define('_MD_TAGMEMO_LIST_E', "List");
define('_MD_TAGMEMO_EDIT_E', "Edit");
define('_MD_TAGMEMO_EDIT_W', "Write");
define('_MD_TAGMEMO_TAGS_E', "Tags");
define('_MD_TAGMEMO_TAGS_N', "New");
define('_MD_TAGMEMO_TAGS_P', "Populer");
define('_MD_TAGMEMO_MESSAGE_DELETE_CONFIRM', "You are going to delete this memo\nAre you sure?"); // check
define('_MD_TAGMEMO_IMG_LIST', "Go to Memolist");
define('_MD_TAGMEMO_IMG_EDIT', "Write new memo ");
define('_MD_TAGMEMO_IMG_CLOUD', "Go to Tag Cloud");
define('_MD_TAGMEMO_TAGCLICK_DELETE', "Click to delete");
define('_MD_TAGMEMO_PLUGIN_FFSEARCH', "Add Search plug-in of Firefox");
define('_MD_TAGMEMO_BOOKMARKLET', "Bookmarklet");
//define('_MD_TAGMEMO_SEARCH', "Search");
//define('_MD_TAGMEMO_SEARCH_ALL', "All");
//define('_MD_TAGMEMO_SEARCH_SUB', "In this list");
define('_MD_TAGMEMO_CLOSE2OPEN', "A bookmarklet was already opened. close it for new one?");
define('_MD_TAGMEMO_NOTWORKFRAME', "Bookmarklet can't work in a frame page.");
define('_MD_TAGMEMO_RETRYPLEASE', "Couldn't show a bookmarklet, please retry.");
?>
